@@ -6,7 +6,6 @@ try:
 except ImportError:
     import xml.etree.ElementTree as ET
 
-
 WEAK_CIPHER_LIST = [
     "TLS_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA",
     "TLS_RSA_WITH_AES_128_CBC_SHA",
@@ -15,9 +14,9 @@ WEAK_CIPHER_LIST = [
     "TLS_RSA_WITH_AES_256_CBC_SHA",
     "TLS_RSA_WITH_AES_256_CBC_SHA256",
     "TLS_RSA_WITH_AES_256_GCM_SHA384",
-    "TLS_RSA_WITH_3DES_EDE_CBC_SHA", 
+    "TLS_RSA_WITH_3DES_EDE_CBC_SHA",
     "TLS_RSA_WITH_CAMELLIA_256_CBC_SHA",
-    "TLS_RSA_WITH_CAMELLIA_128_CBC_SHA" 
+    "TLS_RSA_WITH_CAMELLIA_128_CBC_SHA"
 ]
 
 
@@ -31,7 +30,7 @@ class SslyzeXmlParser:
         self.heart_bleed = self.get_heartbleed(self.parser)
         self.open_ssl_ccs = self.get_openssl_ccs(self.parser)
 
-    def parse_xml(self, xml_output):  
+    def parse_xml(self, xml_output):
         try:
             tree = ET.fromstring(xml_output)
             return tree
@@ -41,7 +40,7 @@ class SslyzeXmlParser:
 
     def get_target(self, tree):
         return tree.xpath('//target')
-                
+
     def get_hostname_validation(self, tree):
         return tree.xpath('//hostnameValidation')
 
@@ -73,7 +72,7 @@ class SslyzeXmlParser:
                         if cipher.attrib['name'] in WEAK_CIPHER_LIST:
                             if not cipher.attrib['name'] in weak_cipher[protocol.tag]:
                                 weak_cipher[protocol.tag].append(cipher.attrib['name'])
-                            
+
         return weak_cipher
 
     def get_heartbleed(self, tree):
@@ -88,15 +87,13 @@ class SslyzePlugin(PluginXMLFormat):
     def __init__(self):
         super().__init__()
         self.identifier_tag = "document"
-        self.id = "Sslyze"
+        self.id = "Sslyze XML"
         self.name = "Sslyze Plugin"
         self.plugin_version = "0.0.1"
         self.version = "2.0.6"
         self.framework_version = "1.0.0"
         self.options = None
         self._current_output = None
-        self._command_regex = re.compile(r'^(sudo sslyze|sslyze|\.\/sslyze)\s+.*?')
-        self.xml_arg_re = re.compile(r"^.*(--xml_output\s*[^\s]+).*$")
         self._use_temp_file = True
         self._temp_file_extension = "xml"
 
@@ -115,75 +112,61 @@ class SslyzePlugin(PluginXMLFormat):
         port = parser.target[0].attrib['port']
         protocol = parser.target[0].attrib['tlsWrappedProtocol']
         cipher = parser.cipher_suite
-        
+
         # Creating host
         host_id = self.createAndAddHost(ip)
-        # Creating service CHANGE NAME                              
+        # Creating service CHANGE NAME
         service_id = self.createAndAddServiceToHost(
-            host_id, 
+            host_id,
             name=protocol,
-            protocol=protocol, 
+            protocol=protocol,
             ports=[port],
-            )
-   
+        )
+
         # Checking if certificate matches
         certificate = parser.certificate[0].attrib['certificateMatchesServerHostname']
         server_hostname = parser.certificate[0].attrib['serverHostname']
         if certificate.lower() == 'false':
             self.createAndAddVulnToService(
-                host_id, 
-                service_id, 
-                name="Certificate mismatch", 
-                desc="Certificate does not match server hostname {}".format(server_hostname), 
+                host_id,
+                service_id,
+                name="Certificate mismatch",
+                desc="Certificate does not match server hostname {}".format(server_hostname),
                 severity="info")
-        #Ciphers
+        # Ciphers
         cipher = parser.cipher_suite
 
         for key in cipher:
             for value in cipher[key]:
                 self.createAndAddVulnToService(
-                    host_id, 
-                    service_id, 
+                    host_id,
+                    service_id,
                     name=value,
-                    desc="In protocol [{}], weak cipher suite: {}".format(key, value), 
+                    desc="In protocol [{}], weak cipher suite: {}".format(key, value),
                     severity="low")
-                        
-        #Heartbleed
+
+        # Heartbleed
         heartbleed = parser.heart_bleed
 
         if heartbleed[0][0].attrib['isVulnerable'].lower() == 'true':
             self.createAndAddVulnToService(
-                host_id, 
-                service_id, 
+                host_id,
+                service_id,
                 name="OpenSSL Heartbleed",
-                desc="OpenSSL Heartbleed is vulnerable", 
+                desc="OpenSSL Heartbleed is vulnerable",
                 severity="critical")
-                                
-        #OpenSsl CCS Injection
+
+        # OpenSsl CCS Injection
         openssl_ccs = parser.open_ssl_ccs
 
         if openssl_ccs[0][0].attrib['isVulnerable'].lower() == 'true':
             self.createAndAddVulnToService(
-                host_id, 
-                service_id, 
+                host_id,
+                service_id,
                 name="OpenSSL CCS Injection",
-                desc="OpenSSL CCS Injection is vulnerable", 
+                desc="OpenSSL CCS Injection is vulnerable",
                 severity="medium")
 
-    def processCommandString(self, username, current_path, command_string):
-        super().processCommandString(username, current_path, command_string)
-        arg_match = self.xml_arg_re.match(command_string)
-        if arg_match is None:
-            return re.sub(r"(^.*?sslyze)",
-                          r"\1 --xml_out %s" % self._output_file_path,
-                          command_string)
-        else:
-            return re.sub(arg_match.group(1),
-                          r"--xml_out %s" % self._output_file_path,
-                          command_string)
-                        
 
 def createPlugin():
     return SslyzePlugin()
-
-# I'm Py3
